UnicodeBlockId

Enum UnicodeBlockId 

pub enum UnicodeBlockId {
Show 277 variants BasicLatin, Latin1Supplement, LatinExtendedA, LatinExtendedB, IPAExtensions, SpacingModifierLetters, CombiningDiacriticalMarks, GreekandCoptic, Cyrillic, CyrillicSupplement, Armenian, Hebrew, Arabic, Syriac, ArabicSupplement, Thaana, NKo, Samaritan, Mandaic, SyriacSupplement, ArabicExtendedA, Devanagari, Bengali, Gurmukhi, Gujarati, Oriya, Tamil, Telugu, Kannada, Malayalam, Sinhala, Thai, Lao, Tibetan, Myanmar, Georgian, HangulJamo, Ethiopic, EthiopicSupplement, Cherokee, UnifiedCanadianAboriginalSyllabics, Ogham, Runic, Tagalog, Hanunoo, Buhid, Tagbanwa, Khmer, Mongolian, UnifiedCanadianAboriginalSyllabicsExtended, Limbu, TaiLe, NewTaiLue, KhmerSymbols, Buginese, TaiTham, CombiningDiacriticalMarksExtended, Balinese, Sundanese, Batak, Lepcha, OlChiki, CyrillicExtendedC, SundaneseSupplement, VedicExtensions, PhoneticExtensions, PhoneticExtensionsSupplement, CombiningDiacriticalMarksSupplement, LatinExtendedAdditional, GreekExtended, GeneralPunctuation, SuperscriptsandSubscripts, CurrencySymbols, CombiningDiacriticalMarksforSymbols, LetterlikeSymbols, NumberForms, Arrows, MathematicalOperators, MiscellaneousTechnical, ControlPictures, OpticalCharacterRecognition, EnclosedAlphanumerics, BoxDrawing, BlockElements, GeometricShapes, MiscellaneousSymbols, Dingbats, MiscellaneousMathematicalSymbolsA, SupplementalArrowsA, BraillePatterns, SupplementalArrowsB, MiscellaneousMathematicalSymbolsB, SupplementalMathematicalOperators, MiscellaneousSymbolsandArrows, Glagolitic, LatinExtendedC, Coptic, GeorgianSupplement, Tifinagh, EthiopicExtended, CyrillicExtendedA, SupplementalPunctuation, CJKRadicalsSupplement, KangxiRadicals, IdeographicDescriptionCharacters, CJKSymbolsandPunctuation, Hiragana, Katakana, Bopomofo, HangulCompatibilityJamo, Kanbun, BopomofoExtended, CJKStrokes, KatakanaPhoneticExtensions, EnclosedCJKLettersandMonths, CJKCompatibility, CJKUnifiedIdeographsExtensionA, YijingHexagramSymbols, CJKUnifiedIdeographs, YiSyllables, YiRadicals, Lisu, Vai, CyrillicExtendedB, Bamum, ModifierToneLetters, LatinExtendedD, SylotiNagri, CommonIndicNumberForms, Phagspa, Saurashtra, DevanagariExtended, KayahLi, Rejang, HangulJamoExtendedA, Javanese, MyanmarExtendedB, Cham, MyanmarExtendedA, TaiViet, MeeteiMayekExtensions, EthiopicExtendedA, LatinExtendedE, CherokeeSupplement, MeeteiMayek, HangulSyllables, HangulJamoExtendedB, PrivateUseArea, CJKCompatibilityIdeographs, AlphabeticPresentationForms, ArabicPresentationFormsA, VariationSelectors, VerticalForms, CombiningHalfMarks, CJKCompatibilityForms, SmallFormVariants, ArabicPresentationFormsB, HalfwidthandFullwidthForms, Specials, LinearBSyllabary, LinearBIdeograms, AegeanNumbers, AncientGreekNumbers, AncientSymbols, PhaistosDisc, Lycian, Carian, CopticEpactNumbers, OldItalic, Gothic, OldPermic, Ugaritic, OldPersian, Deseret, Shavian, Osmanya, Osage, Elbasan, CaucasianAlbanian, LinearA, CypriotSyllabary, ImperialAramaic, Palmyrene, Nabataean, Hatran, Phoenician, Lydian, MeroiticHieroglyphs, MeroiticCursive, Kharoshthi, OldSouthArabian, OldNorthArabian, Manichaean, Avestan, InscriptionalParthian, InscriptionalPahlavi, PsalterPahlavi, OldTurkic, OldHungarian, RumiNumeralSymbols, Brahmi, Kaithi, SoraSompeng, Chakma, Mahajani, Sharada, SinhalaArchaicNumbers, Khojki, Multani, Khudawadi, Grantha, Newa, Tirhuta, Siddham, Modi, MongolianSupplement, Takri, Ahom, WarangCiti, ZanabazarSquare, Soyombo, PauCinHau, Bhaiksuki, Marchen, MasaramGondi, Cuneiform, CuneiformNumbersandPunctuation, EarlyDynasticCuneiform, EgyptianHieroglyphs, AnatolianHieroglyphs, BamumSupplement, Mro, BassaVah, PahawhHmong, Miao, IdeographicSymbolsandPunctuation, Tangut, TangutComponents, KanaSupplement, KanaExtendedA, Nushu, Duployan, ShorthandFormatControls, ByzantineMusicalSymbols, MusicalSymbols, AncientGreekMusicalNotation, TaiXuanJingSymbols, CountingRodNumerals, MathematicalAlphanumericSymbols, SuttonSignWriting, GlagoliticSupplement, MendeKikakui, Adlam, ArabicMathematicalAlphabeticSymbols, MahjongTiles, DominoTiles, PlayingCards, EnclosedAlphanumericSupplement, EnclosedIdeographicSupplement, MiscellaneousSymbolsandPictographs, Emoticons, OrnamentalDingbats, TransportandMapSymbols, AlchemicalSymbols, GeometricShapesExtended, SupplementalArrowsC, SupplementalSymbolsandPictographs, CJKUnifiedIdeographsExtensionB, CJKUnifiedIdeographsExtensionC, CJKUnifiedIdeographsExtensionD, CJKUnifiedIdeographsExtensionE, CJKUnifiedIdeographsExtensionF, CJKCompatibilityIdeographsSupplement, Tags, VariationSelectorsSupplement, SupplementaryPrivateUseAreaA, SupplementaryPrivateUseAreaB,
}
Compile-time identifiers for a Unicode Block.

Use .block() to get a reference to the actual Block instance.

Variants



BasicLatin



Latin1Supplement



LatinExtendedA



LatinExtendedB



IPAExtensions



SpacingModifierLetters



CombiningDiacriticalMarks



GreekandCoptic



Cyrillic



CyrillicSupplement



Armenian



Hebrew



Arabic



Syriac



ArabicSupplement



Thaana



NKo



Samaritan



Mandaic



SyriacSupplement



ArabicExtendedA



Devanagari



Bengali



Gurmukhi



Gujarati



Oriya



Tamil



Telugu



Kannada



Malayalam



Sinhala



Thai



Lao



Tibetan



Myanmar



Georgian



HangulJamo



Ethiopic



EthiopicSupplement



Cherokee



UnifiedCanadianAboriginalSyllabics



Ogham



Runic



Tagalog



Hanunoo



Buhid



Tagbanwa



Khmer



Mongolian



UnifiedCanadianAboriginalSyllabicsExtended



Limbu



TaiLe



NewTaiLue



KhmerSymbols



Buginese



TaiTham



CombiningDiacriticalMarksExtended



Balinese



Sundanese



Batak



Lepcha



OlChiki



CyrillicExtendedC



SundaneseSupplement



VedicExtensions



PhoneticExtensions



PhoneticExtensionsSupplement



CombiningDiacriticalMarksSupplement



LatinExtendedAdditional



GreekExtended



GeneralPunctuation



SuperscriptsandSubscripts



CurrencySymbols



CombiningDiacriticalMarksforSymbols



LetterlikeSymbols



NumberForms



Arrows



MathematicalOperators



MiscellaneousTechnical



ControlPictures



OpticalCharacterRecognition



EnclosedAlphanumerics



BoxDrawing



BlockElements



GeometricShapes



MiscellaneousSymbols



Dingbats



MiscellaneousMathematicalSymbolsA



SupplementalArrowsA



BraillePatterns



SupplementalArrowsB



MiscellaneousMathematicalSymbolsB



SupplementalMathematicalOperators



MiscellaneousSymbolsandArrows



Glagolitic



LatinExtendedC



Coptic



GeorgianSupplement



Tifinagh



EthiopicExtended



CyrillicExtendedA



SupplementalPunctuation



CJKRadicalsSupplement



KangxiRadicals



IdeographicDescriptionCharacters



CJKSymbolsandPunctuation



Hiragana



Katakana



Bopomofo



HangulCompatibilityJamo



Kanbun



BopomofoExtended



CJKStrokes



KatakanaPhoneticExtensions



EnclosedCJKLettersandMonths



CJKCompatibility



CJKUnifiedIdeographsExtensionA



YijingHexagramSymbols



CJKUnifiedIdeographs



YiSyllables



YiRadicals



Lisu



Vai



CyrillicExtendedB



Bamum



ModifierToneLetters



LatinExtendedD



SylotiNagri



CommonIndicNumberForms



Phagspa



Saurashtra



DevanagariExtended



KayahLi



Rejang



HangulJamoExtendedA



Javanese



MyanmarExtendedB



Cham



MyanmarExtendedA



TaiViet



MeeteiMayekExtensions



EthiopicExtendedA



LatinExtendedE



CherokeeSupplement



MeeteiMayek



HangulSyllables



HangulJamoExtendedB



PrivateUseArea



CJKCompatibilityIdeographs



AlphabeticPresentationForms



ArabicPresentationFormsA



VariationSelectors



VerticalForms



CombiningHalfMarks



CJKCompatibilityForms



SmallFormVariants



ArabicPresentationFormsB



HalfwidthandFullwidthForms



Specials



LinearBSyllabary



LinearBIdeograms



AegeanNumbers



AncientGreekNumbers



AncientSymbols



PhaistosDisc



Lycian



Carian



CopticEpactNumbers



OldItalic



Gothic



OldPermic



Ugaritic



OldPersian



Deseret



Shavian



Osmanya



Osage



Elbasan



CaucasianAlbanian



LinearA



CypriotSyllabary



ImperialAramaic



Palmyrene



Nabataean



Hatran



Phoenician



Lydian



MeroiticHieroglyphs



MeroiticCursive



Kharoshthi



OldSouthArabian



OldNorthArabian



Manichaean



Avestan



InscriptionalParthian



InscriptionalPahlavi



PsalterPahlavi



OldTurkic



OldHungarian



RumiNumeralSymbols



Brahmi



Kaithi



SoraSompeng



Chakma



Mahajani



Sharada



SinhalaArchaicNumbers



Khojki



Multani



Khudawadi



Grantha



Newa



Tirhuta



Siddham



Modi



MongolianSupplement



Takri



Ahom



WarangCiti



ZanabazarSquare



Soyombo



PauCinHau



Bhaiksuki



Marchen



MasaramGondi



Cuneiform



CuneiformNumbersandPunctuation



EarlyDynasticCuneiform



EgyptianHieroglyphs



AnatolianHieroglyphs



BamumSupplement



Mro



BassaVah



PahawhHmong



Miao



IdeographicSymbolsandPunctuation



Tangut



TangutComponents



KanaSupplement



KanaExtendedA



Nushu



Duployan



ShorthandFormatControls



ByzantineMusicalSymbols



MusicalSymbols



AncientGreekMusicalNotation



TaiXuanJingSymbols



CountingRodNumerals



MathematicalAlphanumericSymbols



SuttonSignWriting



GlagoliticSupplement



MendeKikakui



Adlam



ArabicMathematicalAlphabeticSymbols



MahjongTiles



DominoTiles



PlayingCards



EnclosedAlphanumericSupplement



EnclosedIdeographicSupplement



MiscellaneousSymbolsandPictographs



Emoticons



OrnamentalDingbats



TransportandMapSymbols



AlchemicalSymbols



GeometricShapesExtended



SupplementalArrowsC



SupplementalSymbolsandPictographs



CJKUnifiedIdeographsExtensionB



CJKUnifiedIdeographsExtensionC



CJKUnifiedIdeographsExtensionD



CJKUnifiedIdeographsExtensionE



CJKUnifiedIdeographsExtensionF



CJKCompatibilityIdeographsSupplement



Tags



VariationSelectorsSupplement



SupplementaryPrivateUseAreaA



SupplementaryPrivateUseAreaB

Implementations

Source

impl UnicodeBlockId

pub fn name(&self) -> &str

Get the block’s name.

pub fn char_range(&self) -> CharRange

Get the block’s CharRange.

pub fn block(&self) -> &'static Block

Get a reference to the Block that this ID represents.